@@ -9,7 +9,7 @@ parent_env_fun <- function(){
 load_packages <- function(packages){
     if(!is.null(packages))
         for(pack in packages)
-            library(substitute(pack), character.only = TRUE)
+            require(substitute(pack), character.only = TRUE)
     invisible()
 }
 
